@@ -44,19 +44,20 @@
 #include <QCoreApplication>
 #include <QProcess>
 #include <QTextStream>
+#include <QFileDialog>
+#include <QAction>
+#include <QPushButton>
+#include <QProgressDialog>
+#include <QInputDialog>
+#include <QTemporaryFile>
 #include <KAboutData>
 #include <KToolBar>
-#include <KFileDialog>
 #include <KMessageBox>
 #include <KIO/Job>
-#include <kio/netaccess.h>
-#include <KPushButton>
-#include <KGlobal>
+#include <KIO/StatJob>
+#include <KJobWidgets>
 #include <KGuiItem>
-#include <KInputDialog>
 #include <KIconLoader>
-#include <KProgressDialog>
-#include <KTemporaryFile>
 #include <QIcon>
 #include <KActionMenu>
 #include <KPluginFactory>
@@ -64,7 +65,7 @@
 #include <KStandardAction>
 #include <KZip>
 #include <KNewStuff3/KNS3/DownloadDialog>
-#include <KAction>
+#include <KConfigGroup>
 #include <QStandardPaths>
 
 #define CFG_GROUP                  "Main Settings"
@@ -101,20 +102,21 @@ static QString partialIcon(bool load=true)
     return name;
 }
 
-class CPushButton : public KPushButton
+class CPushButton : public QPushButton
 {
     public:
 
     CPushButton(const KGuiItem &item, QWidget *parent)
-        : KPushButton(item, parent)
+        : QPushButton(parent)
     {
-        theirHeight=qMax(theirHeight, KPushButton::sizeHint().height());
+        KGuiItem::assign(this, item);
+        theirHeight=qMax(theirHeight, QPushButton::sizeHint().height());
         setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     }
 
     QSize sizeHint() const
     {
-        QSize sh(KPushButton::sizeHint());
+        QSize sh(QPushButton::sizeHint());
 
         sh.setHeight(theirHeight);
         if(sh.width()<sh.height())
@@ -208,22 +210,17 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
                 *fontControlLayout=new QBoxLayout(QBoxLayout::LeftToRight, fontControlWidget);
 
     toolbarLayout->setMargin(0);
-    toolbarLayout->setSpacing(KDialog::spacingHint());
     mainLayout->setMargin(0);
-    mainLayout->setSpacing(KDialog::spacingHint());
     groupsLayout->setMargin(0);
-    groupsLayout->setSpacing(KDialog::spacingHint());
     fontsLayout->setMargin(0);
-    fontsLayout->setSpacing(KDialog::spacingHint());
     fontControlLayout->setMargin(0);
-    fontControlLayout->setSpacing(KDialog::spacingHint());
 
     // Toolbar...
-    KAction     *duplicateFontsAct=new KAction(QIcon::fromTheme("system-search"), i18n("Scan for Duplicate Fonts..."), this);
-                //*validateFontsAct=new KAction(QIcon::fromTheme("checkmark"), i18n("Validate Fonts..."), this);
+    QAction     *duplicateFontsAct=new QAction(QIcon::fromTheme("system-search"), i18n("Scan for Duplicate Fonts..."), this);
+                //*validateFontsAct=new QAction(QIcon::fromTheme("checkmark"), i18n("Validate Fonts..."), this);
 
     if(!Misc::root())
-        itsDownloadFontsAct=new KAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Get New Fonts..."), this);
+        itsDownloadFontsAct=new QAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Get New Fonts..."), this);
     itsToolsMenu=new KActionMenu(QIcon::fromTheme("system-run"), i18n("Tools"), this);
     itsToolsMenu->addAction(duplicateFontsAct);
     //itsToolsMenu->addAction(validateFontsAct);
@@ -237,7 +234,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     itsGroupList=new CGroupList(groupWidget);
     itsGroupListView=new CGroupListView(groupWidget, itsGroupList);
 
-    KPushButton *createGroup=new CPushButton(KGuiItem(QString(), "list-add",
+    QPushButton *createGroup=new CPushButton(KGuiItem(QString(), "list-add",
                                                       i18n("Create a new group")),
                                              groupWidget);
 
@@ -258,7 +255,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     groupsLayout->addWidget(itsDeleteGroupControl, 1, 1);
     groupsLayout->addWidget(itsEnableGroupControl, 1, 2);
     groupsLayout->addWidget(itsDisableGroupControl, 1, 3);
-    groupsLayout->addItem(new QSpacerItem(itsDisableGroupControl->width(), KDialog::spacingHint(),
+    groupsLayout->addItem(new QSpacerItem(itsDisableGroupControl->width(), groupsLayout->spacing(),
                           QSizePolicy::Expanding, QSizePolicy::Fixed), 1, 4);
 
     itsPreviewWidget = new QWidget(this);
@@ -311,7 +308,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
 
     // Layout widgets...
     toolbarLayout->addWidget(toolbar);
-    toolbarLayout->addItem(new QSpacerItem(KDialog::spacingHint(), 2, QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
+    toolbarLayout->addItem(new QSpacerItem(toolbarLayout->spacing(), 2, QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
     toolbarLayout->addWidget(itsFilter);
     mainLayout->addWidget(toolbarWidget);
     mainLayout->addWidget(itsGroupSplitter);
@@ -356,7 +353,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList&)
     itsPreviewMenu->addSeparator();
     CPreviewSelectAction *prevSel=new CPreviewSelectAction(itsPreviewMenu);
     itsPreviewMenu->addAction(prevSel);
-    KAction *changeTextAct=new KAction(QIcon::fromTheme("edit-rename"), i18n("Change Preview Text..."), this);
+    QAction *changeTextAct=new QAction(QIcon::fromTheme("edit-rename"), i18n("Change Preview Text..."), this);
     itsPreviewMenu->addAction(changeTextAct),
 
     itsPreviewListMenu = new QMenu(itsPreviewList);
@@ -489,7 +486,12 @@ void CKCmFontInst::fontsSelected(const QModelIndexList &list)
 
 void CKCmFontInst::addFonts()
 {
-    QList<QUrl> list=KFileDialog::getOpenUrls(QUrl(), CFontList::fontMimeTypes.join(" "), this, i18n("Add Fonts"));
+    QFileDialog dlg(this, i18n("Add Fonts"));
+    dlg.setFileMode(QFileDialog::ExistingFiles);
+    dlg.setMimeTypeFilters(CFontList::fontMimeTypes);
+    QList<QUrl> list;
+    if (dlg.exec() == QDialog::Accepted)
+        list = dlg.selectedUrls();
 
     if(list.count())
     {
@@ -501,7 +503,10 @@ void CKCmFontInst::addFonts()
         {
             if(KFI_KIO_FONTS_PROTOCOL!=(*it).scheme()) // Do not try to install from fonts:/ !!!
             {
-                QUrl url(KIO::NetAccess::mostLocalUrl(*it, this));
+                auto job = KIO::mostLocalUrl(*it);
+                KJobWidgets::setWindow(job, this);
+                job->exec();
+                QUrl url = job->mostLocalUrl();
 
                 if(url.isLocalFile())
                 {
@@ -529,13 +534,15 @@ void CKCmFontInst::groupSelected(const QModelIndex &index)
 
     if(index.isValid())
         grp=static_cast<CGroupListItem *>(index.internalPointer());
+    else
+        return;
 
     itsFontListView->setFilterGroup(grp);
     setStatusBar();
 
     //
     // Check fonts listed within group are still valid!
-    if(grp && grp->isCustom() && !grp->validated())
+    if(grp->isCustom() && !grp->validated())
     {
         QSet<QString>           remList;
         QSet<QString>::Iterator it(grp->families().begin()),
@@ -577,7 +584,7 @@ void CKCmFontInst::print(bool all)
                 static const int constSizes[]={0, 12, 18, 24, 36, 48};
                 QSet<Misc::TFont>::ConstIterator it(fonts.begin()),
                                                  end(fonts.end());
-                KTemporaryFile                   tmpFile;
+                QTemporaryFile                   tmpFile;
                 bool                             useFile(fonts.count()>16),
                                                  startProc(true);
                 QStringList                      args;
@@ -587,6 +594,10 @@ void CKCmFontInst::print(bool all)
                 else
                     itsPrintProc->kill();
 
+                QString title = QGuiApplication::applicationDisplayName();
+                if (title.isEmpty())
+                    title = QCoreApplication::applicationName();
+
                 //
                 // If we have lots of fonts to print, pass kfontinst a tempory groups file to print
                 // instead of passing font by font...
@@ -601,8 +612,8 @@ void CKCmFontInst::print(bool all)
                                 << (*it).styleInfo << endl;
 
                         args << "--embed" << QString().sprintf("0x%x", (unsigned int)window()->winId())
-                             << "--caption" << KGlobal::caption().toUtf8()
-                             << "--icon" << "preferences-desktop-font-installer"
+                             << "--qwindowtitle" << title
+                             << "--qwindowicon" << "preferences-desktop-font-installer"
                              << "--size" << QString().setNum(constSizes[dlg.chosenSize() < 6 ? dlg.chosenSize() : 2])
                              << "--listfile" << tmpFile.fileName()
                              << "--deletefile";
@@ -616,8 +627,8 @@ void CKCmFontInst::print(bool all)
                 else
                 {
                     args << "--embed" << QString().sprintf("0x%x", (unsigned int)window()->winId())
-                         << "--caption" << KGlobal::caption().toUtf8()
-                         << "--icon" << "preferences-desktop-font-installer"
+                         << "--qwindowtitle" << title
+                         << "--qwindowicon" << "preferences-desktop-font-installer"
                          << "--size" << QString().setNum(constSizes[dlg.chosenSize()<6 ? dlg.chosenSize() : 2]);
 
                     for(; it!=end; ++it)
@@ -749,8 +760,13 @@ void CKCmFontInst::zipGroup()
 
         if(grp)
         {
-            QString fileName=KFileDialog::getSaveFileName(QUrl::fromLocalFile(grp->name()), QStringLiteral("application/zip"), this, i18n("Export Group"),
-                                                          KFileDialog::ConfirmOverwrite);
+            QFileDialog dlg(this, i18n("Export Group"));
+            dlg.setAcceptMode(QFileDialog::AcceptSave);
+            dlg.setDirectoryUrl(QUrl::fromLocalFile(grp->name()));
+            dlg.setMimeTypeFilters(QStringList() << QStringLiteral("application/zip"));
+            QString fileName;
+            if (dlg.exec() == QDialog::Accepted)
+                fileName = dlg.selectedFiles().value(0);
 
             if(!fileName.isEmpty())
             {
@@ -795,9 +811,10 @@ void CKCmFontInst::disableFonts()
 void CKCmFontInst::addGroup()
 {
     bool    ok;
-    QString name(KInputDialog::getText(i18n("Create New Group"),
+    QString name(QInputDialog::getText(this, i18n("Create New Group"),
                                        i18n("Please enter the name of the new group:"),
-                                       i18n("New Group"), &ok, this));
+                                       QLineEdit::Normal,
+                                       i18n("New Group"), &ok));
 
     if(ok && !name.isEmpty())
         itsGroupList->createGroup(name);
@@ -821,12 +838,12 @@ void CKCmFontInst::disableGroup()
 
 void CKCmFontInst::changeText()
 {
-    bool             status;
-    QRegExpValidator validator(QRegExp(".*"), 0L);
-    QString          oldStr(itsPreview->engine()->getPreviewString()),
-                     newStr(KInputDialog::getText(i18n("Preview Text"),
-                                                  i18n("Please enter new text:"),
-                                                  oldStr, &status, this, &validator));
+    bool status;
+    QString oldStr(itsPreview->engine()->getPreviewString()),
+            newStr(QInputDialog::getText(this, i18n("Preview Text"),
+                                         i18n("Please enter new text:"),
+                                         QLineEdit::Normal,
+                                         oldStr, &status));
 
     if(status && oldStr!=newStr)
     {
@@ -1052,18 +1069,18 @@ void CKCmFontInst::addFonts(const QSet<QUrl> &src)
 
         if(!itsProgress)
         {
-            itsProgress=new KProgressDialog(this, i18n("Scanning Files..."),
-                                            i18n("Looking for additional files to install..."));
+            itsProgress = new QProgressDialog(this);
+            itsProgress->setWindowTitle(i18n("Scanning Files..."));
+            itsProgress->setLabelText(i18n("Looking for additional files to install..."));
             itsProgress->setModal(true);
             itsProgress->setAutoReset(true);
             itsProgress->setAutoClose(true);
         }
 
-        itsProgress->setAllowCancel(false);
+        itsProgress->setCancelButton(0);
         itsProgress->setMinimumDuration(500);
-        itsProgress->progressBar()->show();
-        itsProgress->progressBar()->setRange(0, src.size());
-        itsProgress->progressBar()->setValue(0);
+        itsProgress->setRange(0, src.size());
+        itsProgress->setValue(0);
 
         int steps=src.count()<200 ? 1 : src.count()/10;
         for(it=src.begin(); it!=end; ++it)
@@ -1071,8 +1088,8 @@ void CKCmFontInst::addFonts(const QSet<QUrl> &src)
             QList<QUrl> associatedUrls;
 
             itsProgress->setLabelText(i18n("Looking for files associated with %1", (*it).url()));
-            itsProgress->progressBar()->setValue(itsProgress->progressBar()->value()+1);
-            if(1==steps || 0==(itsProgress->progressBar()->value()%steps))
+            itsProgress->setValue(itsProgress->value()+1);
+            if(1==steps || 0==(itsProgress->value()%steps))
             {
                 bool dialogVisible(itsProgress->isVisible());
                 QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
